<?php
/*
 * @version $Id: HEADER 2011-03-12 18:01:26 tsmr $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------
// ----------------------------------------------------------------------
// Original Author of file: CAILLAUD Xavier
// Purpose of file: plugin manufacturersimports v1.4.0 - GLPI 0.80
// ----------------------------------------------------------------------
 */

if (!defined('GLPI_ROOT')) {
	die("Sorry. You can't access directly to this file");
}

class PluginManufacturersimportsModel extends CommonDBTM {
   
   static function getTypeName() {
      global $LANG;

      return $LANG['plugin_manufacturersimports']['title'][1];
   }
   
   function canCreate() {
      return plugin_manufacturersimports_haveRight('manufacturersimports', 'w');
   }

   function canView() {
      return plugin_manufacturersimports_haveRight('manufacturersimports', 'r');
   }
   
   static function getClasses () {
	
      static $types = array(
         'Computer','Monitor','NetworkEquipment','Peripheral','Printer'
         );
      
      $plugin = new Plugin();
      if ($plugin->isActivated("racks")) {
         $types[]='PluginRacksRack';
      }
      
      foreach ($types as $key=>$type) {
         if (!class_exists($type)) {
            continue;
         }
         $item = new $type();
         if (!$item->canView()) {
            unset($types[$key]);
         }
      }
      return $types;
   }

	function getFromDBbyDevice($items_id,$itemtype) {
		global $DB;
		
		$query = "SELECT * FROM `".$this->getTable()."` " .
			"WHERE `items_id` = '" . $items_id . "'
			AND `itemtype` = '" . $itemtype . "' ";
		if ($result = $DB->query($query)) {
			if ($DB->numrows($result) != 1) {
				return false;
			}
			$this->fields = $DB->fetch_assoc($result);
			if (is_array($this->fields) && count($this->fields)) {
				return true;
			} else {
				return false;
			}
		}
		return false;
	}
	
   function checkIfModelNeeds($itemtype,$items_id) {

      if ($this->getFromDBbyDevice($items_id,$itemtype))
         return $this->fields["model_name"];
      else
         return false;
   }

  function addModel($items_id,$itemtype,$model_name) {

      if ($this->getFromDBbyDevice($items_id,$itemtype)) {

         $this->update(array(
           'id'=>$this->fields['id'],
           'model_name'=>$model_name,
           'items_id'=>$items_id,
           'itemtype'=>$itemtype));
      } else {

         $this->add(array(
           'model_name'=>$model_name,
           'items_id'=>$items_id,
           'itemtype'=>$itemtype));
      }
   }

   function deleteModel($ID) {

      $this->delete(array('id'=>$ID));

   }
  
   /**
   * Prints the model add form (into devices)
   *
   * @param $device the device ID
   * @param $type the device type
   * @return nothing (print out a table)
   *
   */
   function showForm($itemtype,$items_id) {
      global $DB,$CFG_GLPI,$LANG;
      
      $infocom= new Infocom();
      $canedit=$this->canCreate() && $infocom->canUpdate();

      $query = "SELECT *
          FROM `".$this->getTable()."`
          WHERE `itemtype` = '".$itemtype."'
          AND `items_id` = '".$items_id."'";
      $result = $DB->query($query);
      $number = $DB->numrows($result);

      echo "<form method='post' action=\"".$CFG_GLPI["root_doc"]."/plugins/manufacturersimports/front/import.php\">";
      echo "<div align=\"center\"><table class=\"tab_cadre\"  cellspacing=\"2\" cellpadding=\"2\">";
      echo "<tr><th colspan='2'>".$LANG['plugin_manufacturersimports']['title'][1]."</th></tr>";
      echo "<tr><th colspan='2'>".$LANG['plugin_manufacturersimports']['import'][30]."</th></tr>";

      echo "<tr>";
      echo "<td class='tab_bg_2 left'>";

      if ($number ==1) {
         while($line=$DB->fetch_array($result)) {
            $ID=$line["id"];
            echo "<input type='text' name='model_name' size='30' value='".$line["model_name"]."'>";
            echo "</td>";
            if ($canedit)
               echo "<td class='center' class='tab_bg_2'><a href='".$CFG_GLPI["root_doc"]."/plugins/manufacturersimports/front/import.php?delete_model=delete_model&amp;id=".$ID."'><b>".$LANG['buttons'][6]."</b></a></td>";
         }

      } else if ($canedit) {
         echo "<input type='text' name='model_name' size='30'>";
         echo "</td>";
         echo "</tr>";
         echo "<tr><th colspan='2'><input type='hidden' name='items_id' value='".$items_id."'><input type='hidden' name='itemtype' value='".$itemtype."'><input type=\"submit\" name=\"update_model\" class=\"submit\" value=\"".$LANG['buttons'][2]."\" ></th></tr>";
      }

      echo "</table></div>";
      echo "</form>";
   }
}

?>